Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(119)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/actions/JdtActionConstants.java

Issue 10384142: Initial support for 'Extract temp' - only when single expression selected (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Use ASTVisitor as type switch Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/actions/JdtActionConstants.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/actions/JdtActionConstants.java b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/actions/JdtActionConstants.java
index 1f5ef520916ce77a3ab523acb7bdf421d5721b77..6bd9f1bea81c83e6212315a63473e32209a653ae 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/actions/JdtActionConstants.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/actions/JdtActionConstants.java
@@ -1,16 +1,14 @@
/*
* Copyright (c) 2011, the Dart project authors.
- *
- * Licensed under the Eclipse Public License v1.0 (the "License"); you may not
- * use this file except in compliance with the License. You may obtain a copy of
- * the License at
- *
+ *
+ * Licensed under the Eclipse Public License v1.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the License at
+ *
* http://www.eclipse.org/legal/epl-v10.html
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations under
+ *
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
* the License.
*/
package com.google.dart.tools.ui.actions;
@@ -289,10 +287,10 @@ public class JdtActionConstants {
public static final String RENAME = "com.google.dart.tools.ui.actions.Rename"; //$NON-NLS-1$
/**
* Refactor menu: name of standard Extract Temp global action (value
* <code>"com.google.dart.tools.ui.actions.ExtractTemp"</code>).
*/
- public static final String EXTRACT_TEMP = "com.google.dart.tools.ui.actions.ExtractTemp"; //$NON-NLS-1$
+ public static final String EXTRACT_LOCAL = "com.google.dart.tools.ui.actions.ExtractLocal"; //$NON-NLS-1$
/**
* Refactor menu: name of standard Extract Constant global action (value
@@ -289,10 +287,10 @@ public class JdtActionConstants {
public static final String RENAME = "com.google.dart.tools.ui.actions.Rename"; //$NON-NLS-1$
/**
- * Refactor menu: name of standard Extract Temp global action (value
- * <code>"com.google.dart.tools.ui.actions.ExtractTemp"</code>).
+ * Refactor menu: name of standard Extract Local global action (value
+ * <code>"com.google.dart.tools.ui.actions.ExtractLocal"</code>).
*/

Powered by Google App Engine
This is Rietveld 408576698